==> ubuntuone-dev-tools_3.0.0.orig.tar.gz: ubuntuone-dev-tools-3.0.0/ubuntuone/devtools/reactors/gi.py <==
# Copyright 2009-2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the
# OpenSSL library under certain conditions as described in each
# individual source file, and distribute linked combinations
# including the two.
# You must obey the GNU General Public License in all respects
# for all of the code used other than OpenSSL.  If you modify
# file(s) with this exception, you may extend this exception to your
# version of the file(s), but you are not obligated to do so.  If you
# do not wish to do so, delete this exception statement from your
# version.  If you delete this exception statement from all source
# files in the program, then also delete it here.
"""The introspection based main loop integration reactor for testing."""

REACTOR_URL = 'http://twistedmatrix.com/trac/ticket/4558'


def install(options=None):
    """Install the reactor and parse any options we might need."""
    reactor_name = None
    if options is not None and options['gui']:
        reactor_name = 'twisted.internet.gtk3reactor'
    else:
        reactor_name = 'twisted.internet.gireactor'

    glibreactor = __import__(reactor_name, None, None, [''])
    glibreactor.install()

==> ubuntuone-dev-tools_13.10.orig.tar.gz: ubuntuone-dev-tools-13.10/ubuntuone/devtools/reactors/gi.py <==
# Copyright 2009-2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the
# OpenSSL library under certain conditions as described in each
# individual source file, and distribute linked combinations
# including the two.
# You must obey the GNU General Public License in all respects
# for all of the code used other than OpenSSL.  If you modify
# file(s) with this exception, you may extend this exception to your
# version of the file(s), but you are not obligated to do so.  If you
# do not wish to do so, delete this exception statement from your
# version.  If you delete this exception statement from all source
# files in the program, then also delete it here.
"""The introspection based main loop integration reactor for testing."""

REACTOR_URL = 'http://twistedmatrix.com/trac/ticket/4558'


def load_reactor(reactor_name=None):
    """Load the reactor module and return it."""
    return __import__(reactor_name, None, None, [''])


def install(options=None):
    """Install the reactor and parse any options we might need."""
    reactor = None
    if options is not None and options['gui']:
        try:
            reactor = load_reactor('twisted.internet.gtk3reactor')
        except ImportError:
            print('Falling back to gtk2reactor module.')
            reactor = load_reactor('twisted.internet.gtk2reactor')
    else:
        try:
            reactor = load_reactor('twisted.internet.gireactor')
        except ImportError:
            print('Falling back to glib2reactor module.')
            reactor = load_reactor('twisted.internet.glib2reactor')

    reactor.install()
